@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -260,6 +260,8 @@ public:
 	void setImage(const std::string &image);
 	const std::string &getAddress() const;
 	void setAddress(const std::string &address);
+	const std::string &getInterface() const;
+	void setInterface(const std::string &interface);
 	bool getForce() const;
 	void setForce(bool force);
 
@@ -278,6 +280,8 @@ protected:
 	std::string _device;
 	/// Ip address entered by the user
 	std::string _address;
+	/// Ip address of the interface to be used in the link mode
+	std::string _interface;
 	/// Number of receivers entered by the user
 	unsigned int _nodesNumber;
 	/// Empty mode enabled/disabled
