@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #include <sys/types.h>
 
 #include <map>
+#include <vector>
+
+#include <archive.h>
 
 #include <doclone/observer/AbstractSubject.h>
 #include <doclone/exception/Exception.h>
@@ -71,15 +74,11 @@ typedef ssize_t (*writeFunction) (int, const void*, size_t);
  * \class DataTransfer
  * \brief Singleton interface to get, set up and use the file/socket descriptors
  *
- * This class provides a set of methods to abstract the reading and writing
- * of data. In this program, all the data is written/read using descriptors,
- * whether file descriptors or sockets. Trough this class the library sets if
- * the origin or destination of the data is a descriptor of socket or file. And
- * provides a couple of methods to get the descriptors from any place of the
- * code.
+ * This class provides a set of utility methods for abstracting the reading and
+ * writing of data with libarchive.
  *
  * For work in multicast, the server establishes a TCP connection with all the
- * receivers. For this reason, this class has the list of descriptors
+ * receivers. For this reason, this class has the map of descriptors
  * this->_fdd, with its corresponding IP addresses.
  *
  * This class is singleton.
@@ -87,45 +86,33 @@ typedef ssize_t (*writeFunction) (int, const void*, size_t);
  */
 class DataTransfer : public AbstractSubject {
 public:
-	~DataTransfer();
+	~DataTransfer() {}
 	static DataTransfer* getInstance();
 
-	uint64_t transferAllFrom(int fd) throw(Exception);
-	uint64_t transferFrom(int fd, uint64_t nBytes) throw(Exception);
-	uint64_t transferFrom(const void *buff, uint64_t count) throw(Exception);
+	uint64_t archiveToBuf(struct archive *arIn, std::string &target) throw(Exception);
+	uint64_t bufToArchive(const std::string &source, std::vector<struct archive*> &outArchives) throw(Exception);
+	uint64_t fdToArchive(int fd, std::vector<struct archive*> &outArchives) throw(Exception);
+	uint64_t copyData(struct archive *arIn, std::vector<struct archive *> &outArchives) throw(Exception);
+	uint64_t copyData(int fdin, std::vector<int> &outFds) throw(Exception);
+	uint64_t copyData(int fdin, int fdout) throw(Exception);
+	void copyHeader(struct archive_entry *entry, std::vector<struct archive*> &outArchives) throw(Exception);
 
-	uint64_t transferAllTo(int fd) throw(Exception);
-	uint64_t transferTo(int fd, uint64_t nBytes) throw(Exception);
-	uint64_t transferTo(void *buff, uint64_t count) throw(Exception);
+	void initLocalRead();
+	void initSocketRead();
+	void initLocalWrite();
+	void initSocketWrite();
 
 	static ssize_t readBytes (int s, void *buf, size_t len) throw (Exception);
 	static ssize_t recvData (int s, void *buf, size_t len) throw (Exception);
 	static ssize_t writeBytes (int s, const void *buf, size_t len) throw (Exception);
 	static ssize_t sendData (int s, const void *buf, size_t len) throw (Exception);
-	static ssize_t sendMultiple (int s, const void *buf, size_t len) throw (Exception);
+	static ssize_t sendData (std::vector<int> &fds, const void *buf, size_t len) throw (Exception);
 
-	void initFileRead();
-	void initSocketRead();
-	void initFileWrite();
-	void initSocketWrite();
-	void initSocketMultiple();
-
-	void setFdo(int fdo);
-	int getFdo() const;
-
-	void setFdd(int fdd, std::string host);
-	int getFdd() const;
-
-	void setTotalSize(uint64_t size);
+	void setTotalSize(const uint64_t size);
 
 	uint64_t getTotalSize() const;
 	uint64_t getTransferredBytes() const;
 
-	void pushFdd(int fdd, std::string host);
-	const std::map<int,std::string> &getFddList() const;
-
-	void removeFdd(int fdd);
-
 	/// Can be defined as read() or recv()
 	Doclone::readFunction getNbytes;
 
@@ -135,15 +122,14 @@ private:
 	/// Private constructor is needed in Singleton pattern
 	DataTransfer();
 
-	/// The descriptor of origin
-	int _fdo;
-	/// The list of destination descriptors
-	std::map<int,std::string> _fdd;
-
 	/// Total size to transfer
 	uint64_t _totalSize;
 	/// Transferred bytes at the moment
 	uint64_t _transferredBytes;
+	/// Observers are be notified every time this amount of bytes is written
+	uint32_t _notificationPointSize;
+	/// Number of times the observers have been notified at the moment
+	uint32_t _transferNotificationsCount;
 };
 
 }
