@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,9 @@
 
 namespace Doclone {
 
+/// Size of the Master Boot Record of the disk
+const uint16_t MBR_SIZE = 440;
+
 /**
  * \class Disk
  * \brief Represents a full disk.
@@ -41,24 +44,25 @@ namespace Doclone {
  */
 class Disk {
 public:
-	Disk(const std::string &path) throw(Exception);
+	Disk();
 	virtual ~Disk();
-	
+
 	virtual void readBootCode() throw(Exception);
 	virtual void writeBootCode() const throw(Exception);
 	virtual void readPartitions() throw(Exception);
 	virtual void writePartitions() const throw(Exception);
-	
+
+	void initFromPath(const std::string &path) throw(Exception);
 	void restoreGrub() throw(Exception);
 
 	void setPath(const std::string &path);
 	const std::string &getPath() const;
 	void setSize(uint64_t size);
 	uint64_t getSize() const;
-	const std::vector<Partition*> &getPartitions() const;
+	std::vector<Partition*> &getPartitions();
 	void setPartitions(const std::vector<Partition*> &parts);
-	const void *getBootCode() const;
-	void setBootCode(const void *bCode);
+	const char *getBootCode() const;
+	void setBootCode(const char *bCode);
 
 protected:
 	/// The disk path
@@ -68,8 +72,8 @@ protected:
 	/// Vector of partitions that will be read of written from/to the disk
 	std::vector<Partition*> _partitions;
 	/// The Master Boot Record of the disk. The first 440 bytes that contains the code to boot
-	char _bootCode[440];
-	
+	char _bootCode[Doclone::MBR_SIZE];
+
 	void initSize() throw(Exception);
 
 	PedGeometry *calcGeometry(const PedDisk* pDisk,
@@ -77,7 +81,7 @@ protected:
 	PedConstraint *calcConstraint(const PedPartition* pPart,
 			uint64_t usedBytes) const throw(Exception);
 	void writePartitionToDisk(Partition *part) const throw(Exception);
-	
+
 	virtual void makeLabel() const throw(Exception) = 0;
 };
 
