@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,12 +60,13 @@ enum diskLabelType {DISK_TYPE_NONE, DISK_TYPE_AIX, DISK_TYPE_BSD,
  */
 class DiskLabel : public Disk {
 public:
-	DiskLabel(const std::string &path);
+	DiskLabel();
 	virtual ~DiskLabel() {}
 
 	void makeLabel() const throw(Exception);
 
 	Doclone::diskLabelType getLabelType() const;
+	void setLabelType(Doclone::diskLabelType labelType);
 protected:
 	/// The type of the partition table
 	Doclone::diskLabelType _labelType;
