@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define DLFACTORY_H_
 
 #include <doclone/DiskLabel.h>
+#include <doclone/exception/Exception.h>
 
 namespace Doclone {
 
@@ -34,9 +35,8 @@ namespace Doclone {
  */
 class DlFactory {
 public:
-	static DiskLabel *createDiskLabel();
-	static DiskLabel *createDiskLabel(diskLabelType dlType,
-			const std::string &path);
+	static DiskLabel *createDiskLabel() throw(Exception);
+	static DiskLabel *createDiskLabel(diskLabelType dlType);
 };
 
 } /* namespace Doclone */
