@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -137,24 +137,21 @@ public:
 	const std::string &getMountOptions() const;
 	const std::string &getCommand() const;
 	const std::string &getFormatOptions() const;
+	const std::string &getLabel() const;
+	const std::string &getUUID() const;
 	bool getMountSupport() const;
 	bool getFormatSupport() const;
 	bool getUUIDSupport() const;
 	bool getLabelSupport() const;
 	void setLabel(const std::string &label);
 	void setUUID(const std::string &uuid);
-	const std::string &getMountPoint() const;
-	void setMountPoint(const std::string &path);
-	
-	std::string readLabel(const std::string &dev) const throw(Exception);
-	std::string readUUID(const std::string &dev) const throw(Exception);
+
+	void readLabel(const std::string &dev) throw(Exception);
+	void readUUID(const std::string &dev) throw(Exception);
 
 	virtual void writeLabel(const std::string &dev) const throw(Exception) {}
 	virtual void writeUUID(const std::string &dev) const throw(Exception) {}
 
-	virtual void readDir(const std::string &path) throw(Exception) {}
-	virtual void writeDir(const std::string &path) throw(Exception) {}
-
 protected:
 	/// If the mount is native or external
 	Doclone::mountType _mountType;
@@ -175,12 +172,10 @@ protected:
 	/// Command to format
 	std::string _command;
 	/// Options to the format command
-	std::string _formatOptions; 
+	std::string _formatOptions;
 	/// Command to admin
 	std::string _adminCommand;
-	/// Path to the mount point
-	std::string _mountPoint;
-	
+
 	/// If it has mounting support
 	bool _mountSupport;
 	/// If it has formatting support
