@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,16 +42,16 @@ namespace Doclone {
  */
 class Grub {
 public:
-	Grub(const Disk *disk) throw(Exception);
+	Grub( Disk *disk) throw(Exception);
 	~Grub();
 	void install() throw(Exception);
-	
+
 private:
 	/// The device on which work
-	const Disk *_disk;
+	Disk *_disk;
 	/// Vector of partitions where maybe grub is installed
 	std::map<unsigned int, std::string> _grubParts;
-	
+
 	void searchPartition() throw(Exception);
 };
 
