@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,11 +23,16 @@
 #include <sys/types.h>
 
 #include <string>
-#include <vector>
+
+#include <archive.h>
+#include <archive_entry.h>
+
+#include <xercesc/dom/DOM.hpp>
 
 #include <doclone/Util.h>
 #include <doclone/DiskLabel.h>
 #include <doclone/Partition.h>
+#include <doclone/xml/XMLDocument.h>
 #include <doclone/exception/Exception.h>
 
 namespace Doclone {
@@ -43,27 +48,6 @@ namespace Doclone {
  */
 enum imageType { IMAGE_DISK, IMAGE_PARTITION };
 
-/**
- * \struct imageHeader
- * \brief Metadata of the image
- *
- * Will be part of the image file.
- */
-struct imageHeader {
-	/// Number of partitions in the image
-	uint8_t num_partitions;
-	/// Estimated Total size of the resultant image, in bytes
-	uint64_t image_size;
-	/// Value of imageType enumerator: Disk or partition image
-	uint8_t image_type;
-	/// Disk boot_code (if any)
-	uint8_t boot_code[440];
-	/// Value of diskLabelType enumerator.
-	uint8_t disk_type;
-	/// For future features
-	uint8_t dummy[512];
-};
-
 /**
  * \class Image
  * \brief Represents a doclone image.
@@ -79,57 +63,65 @@ struct imageHeader {
 class Image {
 public:
 	Image();
-	virtual ~Image();
-	
+	~Image();
+
 	bool isValid() const throw(Exception);
 
-	void openImageHeader() throw(Exception);
-	void createImageHeader(Disk *dcDev) throw(Exception);
+	void initDiskReadArchive();
+	void initFdReadArchive(const int fdin) throw(Exception);
+	void initDiskWriteArchive();
+	void initFdWriteArchive(std::vector<int> &fds) throw(Exception);
+	void initFdWriteArchive(const int fdout) throw(Exception);
 
-	ssize_t readImageHeader(const std::string &device) throw(Exception);
-	ssize_t writeImageHeader() const throw(Exception);
+	void freeReadArchive();
+	void freeWriteArchive();
 
-	void readPartitionsData() const throw(Exception);
-	void writePartitionsData() const throw(Exception);
+	void loadImageSizeFromHeader() throw(Exception);
+	void loadImageHeader() throw(Exception);
+	void saveImageHeader() throw(Exception);
+
+	void readPartitionsData() throw(Exception);
+	void writePartitionsData(const std::string &device) throw(Exception);
 
 	void readPartitionTable(const std::string &device) throw(Exception);
 	void writePartitionTable(const std::string &device) throw(Exception);
 
 	bool canCreateCheck() const throw(Exception);
-	bool canRestoreCheck(const std::string &device, uint64_t size) const throw(Exception);
+	bool canRestoreCheck(const std::string &device) const throw(Exception);
 
 	void initCreateOperations() throw(Exception);
 	void initRestoreOperations(const std::string &device) const throw(Exception);
 
-    Doclone::imageType getType() const;
-    void setType(Doclone::imageType type);
-
-    Doclone::imageHeader getHeader() const;
-    void setHeader(Doclone::imageHeader header);
-
-    const std::vector<Partition*> &getPartitions() const;
-    Doclone::diskLabelType getLabelType() const;
+	uint64_t getSize() const;
+	Doclone::imageType getType() const;
+	void setType(Doclone::imageType type);
+	Disk *getDisk();
+	struct archive *getArchiveIn() const;
+	const std::vector<struct archive *> &getArchivesOut() const;
 
 private:
 	/// Image size
 	uint64_t _size;
 	/// Image type (disk or partition)
 	Doclone::imageType _type;
-	/// The type of the disk label (only used if the disk is a partition)
-	Doclone::diskLabelType _labelType;
 	/// If the image has data or only a partition table
 	bool _noData;
-	/// Metadata of the image
-	Doclone::imageHeader _header;
-	/// All partitions of the image
-	std::vector<Partition*> _partitions;
-	/// Information about all partitions of the image
-	std::vector<Doclone::partInfo> _partsInfo;
+	/// Disk to work on
+	DiskLabel *_disk;
+	/// The reading archive object
+	struct archive *_archiveIn;
+	/// Vector of writing archive objects
+	std::vector<struct archive *> _archivesOut;
 
-	bool fitInDisk(uint64_t size) const throw(Exception);
+	bool fitInDisk() const throw(Exception);
 
-	void readPartition(int index) const throw(Exception);
+	void readPartition(int index) throw(Exception);
 	void writePartition(int index) const throw(Exception);
+
+	void readDataFromDisk(struct archive_entry_linkresolver *lResolv,
+			const std::string &path, const std::string &imgRootDir,
+			size_t mPointLength) throw(Exception);
+	void writeDataToDisk() throw(Exception);
 };
 
 }
