@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 
 #include <parted/parted.h>
 
+#include <doclone/exception/Exception.h>
+
 namespace Doclone {
 
 /**
@@ -36,33 +38,35 @@ namespace Doclone {
 class PartedDevice {
 public:
 	~PartedDevice();
-	
+
 	static PartedDevice* getInstance();
-	
+
 	void initialize(const std::string &device);
-	
+
 	std::string getPath();
 	PedDevice *getDevice() ;
 	PedDisk *getDisk();
+	PedPartition *getPartition(unsigned int numPartition) const;
 	void setDisk(PedDisk *pDisk);
 	uint64_t getDevSize() const;
-	
-	void open();
-	void commit() const;
-    void close();
-	 
+	uint64_t getPartitionSize(unsigned int numPartition) const;
+
+	void open() throw(Exception);
+	void commit() const throw(Exception);
+	void close();
+
 private:
-    /// Private constructor to implement singleton pattern
-    PartedDevice();
-    
-    /// Used to know if a new parted disk or device must be opened or closed.
-    int _openings;
-    /// The path of the disk what we work in
-    std::string _path;
-    /// Libparted device object
-    PedDevice* _pDevice;
-    /// Libparted disk object
-    PedDisk* _pDisk;
+	/// Private constructor to implement singleton pattern
+	PartedDevice();
+
+	/// Used to know if a new parted disk or device must be opened or closed.
+	int _openings;
+	/// The path of the disk what we work in
+	std::string _path;
+	/// Libparted device object
+	PedDevice* _pDevice;
+	/// Libparted disk object
+	PedDisk* _pDisk;
 };
 
 }
