@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -78,36 +78,6 @@ const dcFlag F_DIAG					= 1 << 13;
  */
 enum partType {PARTITION_PRIMARY, PARTITION_LOGICAL, PARTITION_EXTENDED};
 
-/**
- * \struct partInfo
- * \brief Contains all the data necessary to restore a partition in the
- * destination
- *
- * All its data is contained in fixed-size variables, in order to make the
- * transfer over the network safer and compatible with 32 and 64 bits
- * processors.
- */
-struct partInfo {
-	/// Flags for this partition
-	dcFlag flags;
-	/// Percentage that represents the position of this partition in the disk
-	uint64_t start_pos;
-	/// Percentage of disk used by the partition
-	uint64_t used_part;
-	/// Value of partType enumerator: Logical, primary, extended
-	uint8_t type;
-	/// Minimum size of the partition (bytes)
-	uint64_t min_size;
-	/// The name for filesystem in libdoclone
-	uint8_t fsName[32];
-	/// The partition's label
-	uint8_t label[28];
-	/// The partition's uuid
-	uint8_t uuid[37];
-	/// For future features
-	uint8_t dummy[512];
-};
-
 /**
  * \class Partition
  * \brief Partition of the hard disk.
@@ -119,36 +89,44 @@ struct partInfo {
  */
 class Partition {
 public:
-	Partition(const std::string &path) throw(Exception);
-	Partition(Doclone::partInfo header) throw(Exception);
+	Partition();
 	~Partition();
-	
+
 	// Getters and setters
 	Doclone::partType getType() const;
+	void setType(Doclone::partType type);
 	uint64_t getMinSize() const;
+	void setMinSize(uint64_t minSize);
 	double getStartPos() const;
+	void setStartPos(double startPos);
 	double getUsedPart() const;
-	Doclone::partInfo getPartition() const;
-	void setPath(const std::string &path);
+	void setUsedPart(double usedPart);
 	const std::string &getPath() const;
-	void setPartNum(unsigned int);
+	Doclone::dcFlag getFlags() const;
+	void setFlags(Doclone::dcFlag flags);
+	void setPath(const std::string &path);
 	unsigned int getPartNum() const;
-	Filesystem * getFileSystem();
-	
+	void setPartNum(unsigned int);
+	Filesystem *getFileSystem() const;
+	void setFileSystem(Filesystem *fs);
+	const std::string &getMountPoint() const;
+	const std::string &getRootDir() const;
+	void setRootDir(const std::string &rootDir);
+
+	void initFromPath(const std::string &path) throw(Exception);
+
+	void clearSignatures() const throw(Exception);
 	void format() const throw(Exception);
 	void writeLabel() const throw(Exception);
 	void writeUUID() const throw(Exception);
 	void writeFlags() const throw(Exception);
-	
+
 	void doMount() throw(Exception);
 	void doUmount() throw(Exception);
-	
-	void createPartInfo() throw(Exception);
-	void read() throw(Exception);
-	void write() throw(Exception);
-	
+	bool isMounted() throw(Exception);
+
 	bool isWritable() const throw(Exception);
-	bool fitInDevice() throw(Exception);
+	bool fitInDevice(bool diskImage) throw(Exception);
 
 private:
 	/// The partition path
@@ -167,16 +145,13 @@ private:
 	Doclone::partType _type;
 	/// Flags of the partition
 	Doclone::dcFlag _flags;
-	/// Fs Label
-	std::string _label;
-	/// Fs uuid
-	std::string _uuid;
-	/// Metadata of the partition
-	Doclone::partInfo _partition;
-	
-	bool isMounted() throw(Exception);
+	/// Path to the mount point
+	std::string _mountPoint;
+	/// Root directory of the partition in the image header
+	std::string _rootDir;
+
 	void externalMount() throw(Exception);
-	
+
 	// Initialize functions
 	void initNum() throw(Exception);
 	void initType() throw(Exception);
@@ -185,13 +160,10 @@ private:
 	void initStartPos() throw(Exception);
 	void initUsedPart() throw(Exception);
 	void initFlags() throw(Exception);
-	void initLabel() throw(Exception);
-	void initUUID() throw(Exception);
-	
+
 	uint64_t usedSpace() throw(Exception);
 };
 
 }
 
 #endif /* PARTITION_H_ */
-
