@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,34 +20,45 @@
 #define UNICAST_H_
 
 #include <string>
+#include <vector>
 
-#include <doclone/Net.h>
+#include <doclone/NetNode.h>
 #include <doclone/exception/Exception.h>
 
 namespace Doclone {
 
 /**
  * \class Unicast
- * \brief Implementation of the unicast/multicast mode.
+ * \brief Implementation of the unicast/multicast server and client.
  *
  * Methods and attributes to clone over network using unicast or multicast.
  * Class inherited from Net.
  * \date August, 2011
  */
-class Unicast : public Net {
+class Unicast : public NetNode {
 public:
+	Unicast();
+
 	void send() throw(Exception);
 	void receive() throw(Exception);
 
 private:
+	virtual void closeConnection() throw(Exception);
+
 	void tcpServer() throw(Exception);
-	void tcpClient() const throw(Exception);
+	void tcpClient() throw(Exception);
 
-	void sendFromImage(const std::string &image) throw(Exception);
-	void sendFromDevice(const std::string &device) throw(Exception);
+	void sendFromImage() throw(Exception);
+	void sendFromDevice() throw(Exception);
 
-	void receiveToImage(const std::string &image) const throw(Exception);
-	void receiveToDevice(const std::string &device) const throw(Exception);
+	void receiveToImage() throw(Exception);
+	void receiveToDevice() throw(Exception);
+
+	/// Number of receivers (for server)
+	unsigned int _nodesNum;
+
+	///Vector of sockets connected to the client or server
+	std::vector<int> _fds;
 };
 
 }
