@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,10 +33,20 @@ namespace Doclone {
  */
 class FormatException : public WarningException {
 public:
-	FormatException() throw() {
-		this->_msg=D_("Can't format partition");
-	}
+	/// \param device The path of the partition
+	FormatException(const std::string &device) throw() : _device(device) {
+		// TO TRANSLATORS: looks like	Can't format partition: /dev/sdb1
+		std::string msg= D_("Can't format partition:");
+		msg.append(" ");
+		msg.append(this->_device);
 
+		this->_msg = msg;
+	}
+	~FormatException() throw() {}
+
+private:
+	/// The path of the partition
+	const std::string _device;
 };
 /**@}*/
 
