@@ -21,7 +21,7 @@
 
 #include <string>
 
-#include <doclone/UnixFS.h>
+#include <doclone/Filesystem.h>
 #include <doclone/exception/Exception.h>
 
 namespace Doclone {
@@ -45,13 +45,13 @@ namespace Doclone {
  * Functions to write the label and uuid of a ext2/3/4 filesystem
  * \date August, 2011
  */
-class Ext2 : public UnixFS {
+class Ext2 : public Filesystem {
 public:
 	Ext2();
-	
+
 	void writeLabel(const std::string &dev) const throw(Exception);
 	void writeUUID(const std::string &dev) const throw(Exception);
-	
+
 private:
 	virtual void checkSupport();
 };
