@@ -21,7 +21,7 @@
 
 #include <string>
 
-#include <doclone/DosFS.h>
+#include <doclone/Filesystem.h>
 #include <doclone/exception/Exception.h>
 
 namespace Doclone {
@@ -45,10 +45,10 @@ namespace Doclone {
  * Writes uuid and label
  * \date August, 2011
  */
-class Fat32 : public DosFS {
+class Fat32 : public Filesystem {
 public:
 	Fat32();
-	
+
 	void writeLabel(const std::string &dev) const throw(Exception);
 	void writeUUID(const std::string &dev) const throw(Exception);
 
