@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013, 2014 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013-2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include <pthread.h>
 
 #include <doclone/Logger.h>
-#include <doclone/Local.h>
+#include <doclone/LocalNode.h>
 #include <doclone/DataTransfer.h>
 #include <doclone/PartedDevice.h>
 #include <doclone/Util.h>
@@ -39,7 +39,7 @@ namespace Doclone {
 /**
  * \brief Initializes gettext, signal handlers and some attributes of this class
  */
-Clone::Clone(): _image(), _device(), _address(), _nodesNumber(0),
+Clone::Clone(): _image(), _device(), _address(), _interface(), _nodesNumber(0),
 		_empty(false), _force(), _operations() {
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
@@ -81,21 +81,14 @@ void Clone::create() throw(Exception) {
 	try {
 		PartedDevice *pedDev = PartedDevice::getInstance();
 		pedDev->initialize(Util::getDiskPath(this->_device));
+
 		DataTransfer *trns = DataTransfer::getInstance();
 
-		trns->initFileRead();
-		trns->initFileWrite();
-
-		Util::createFile(this->_image);
-		int fd = Util::openFile(this->_image);
-
-		trns->setFdd(fd, "");
-
-		Local local(this->_image, this->_device);
+		trns->initLocalRead();
+		trns->initLocalWrite();
 
+		LocalNode local;
 		local.create();
-
-		Util::closeFile(fd);
 	} catch(const ErrorException &ex) {
 		// Alert to view
 		this->notifyObservers(Doclone::EVT_CANCEL_EXECUTION, "");
@@ -124,19 +117,11 @@ void Clone::restore() throw(Exception) {
 		pedDev->initialize(Util::getDiskPath(this->_device));
 
 		DataTransfer *trns = DataTransfer::getInstance();
+		trns->initLocalRead();
+		trns->initLocalWrite();
 
-		trns->initFileRead();
-		trns->initFileWrite();
-
-		int fd = Util::openFile(this->_image);
-
-		trns->setFdo(fd);
-
-		Local local(this->_image, this->_device);
-
+		LocalNode local;
 		local.restore();
-
-		Util::closeFile(fd);
 	} catch(const ErrorException &ex) {
 		// Alert to view
 		this->notifyObservers(Doclone::EVT_CANCEL_EXECUTION, "");
@@ -162,19 +147,11 @@ void Clone::send() throw(Exception) {
 	log->debug("doclone::send() start");
 
 	DataTransfer *trns = DataTransfer::getInstance();
-	trns->initFileRead();
-
-	if(this->_nodesNumber == 0
-			|| this->_nodesNumber == 1) {
-		trns->initSocketWrite();
-	}
-	else {
-		trns->initSocketMultiple();
-	}
+	trns->initLocalRead();
+	trns->initSocketWrite();
 
 	try {
 		Unicast unicast;
-
 		unicast.send();
 	} catch(const ErrorException &ex) {
 		// Alert to view
@@ -202,11 +179,10 @@ void Clone::receive() throw(Exception) {
 
 	DataTransfer *trns = DataTransfer::getInstance();
 	trns->initSocketRead();
-	trns->initFileWrite();
+	trns->initLocalWrite();
 
 	try {
 		Unicast unicast;
-
 		unicast.receive();
 	} catch(const ErrorException &ex) {
 		// Alert to view
@@ -232,12 +208,11 @@ void Clone::chainOrigin() throw(Exception) {
 	log->debug("doclone::chainOrigin() start");
 
 	DataTransfer *trns = DataTransfer::getInstance();
-	trns->initFileRead();
+	trns->initLocalRead();
 	trns->initSocketWrite();
 
 	try {
 		Link lnk;
-
 		lnk.send();
 	} catch(const ErrorException &ex) {
 		// Alert to view
@@ -264,11 +239,10 @@ void Clone::chainLink() throw(Exception) {
 
 	DataTransfer *trns = DataTransfer::getInstance();
 	trns->initSocketRead();
-	trns->initFileWrite();
+	trns->initLocalWrite();
 
 	try {
 		Link lnk;
-
 		lnk.receive();
 	} catch(const ErrorException &ex) {
 		// Alert to view
@@ -355,6 +329,21 @@ void Clone::setAddress(const std::string &address) {
 	this->_address = address;
 }
 
+const std::string &Clone::getInterface() const {
+	return this->_interface;
+}
+
+/**
+ * \ingroup CPPAPI
+ * \brief Sets the IP address of the network interface to be used in the link mode.
+ *
+ * \param interface
+ * 		IP Address of the interface
+ */
+void Clone::setInterface(const std::string &interface) {
+	this->_interface = interface;
+}
+
 bool Clone::getForce() const {
 	return this->_force;
 }
@@ -435,7 +424,7 @@ Operation* Clone::getOperation(dcOperationType type, const std::string &target)
 		}
 	}
 
-	log->debug("doclone::getOperation() start");
+	log->debug("doclone::getOperation(op=>0x%x) start", op);
 
 	return op;
 }
