@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #include <sstream>
 #include <fstream>
+#include <vector>
 
 #include <parted/parted.h>
 
@@ -41,14 +42,10 @@
 namespace Doclone {
 
 /**
- * \brief Initialize attributes. Called to create an image
- *
- * \param path
- * 		The disk path
+ * \brief Initialize attributes.
  */
-Disk::Disk(const std::string &path) throw(Exception)
-		: _path(path), _size(), _partitions(), _bootCode() {
-	this->initSize();
+Disk::Disk()
+		: _path(), _size(), _partitions(), _bootCode() {
 }
 
 // Getters and setters
@@ -68,7 +65,7 @@ void Disk::setSize(uint64_t size) {
 	this->_size = size;
 }
 
-const std::vector<Partition*> &Disk::getPartitions() const {
+std::vector<Partition*> &Disk::getPartitions() {
 	return this->_partitions;
 }
 
@@ -76,16 +73,27 @@ void Disk::setPartitions(const std::vector<Partition*> &parts) {
 	this->_partitions = parts;
 }
 
-const void *Disk::getBootCode() const {
+const char *Disk::getBootCode() const {
 	return this->_bootCode;
 }
 
-void Disk::setBootCode(const void *bCode) {
+void Disk::setBootCode(const char *bCode) {
 	memcpy(this->_bootCode, bCode, sizeof(this->_bootCode));
 }
 
 /**
- * \brief Reads the first 440 bytes of the disk
+ * \brief Initializes the disk from its path.
+ *
+ * \param path
+ * 		The disk path. e.g. /dev/sda
+ */
+void Disk::initFromPath(const std::string &path) throw(Exception) {
+	this->_path = path;
+	this->initSize();
+}
+
+/**
+ * \brief Reads the first Doclone::MBR_SIZE bytes of the disk
  */
 void Disk::readBootCode() throw(Exception) {
 	Logger *log = Logger::getInstance();
@@ -100,7 +108,7 @@ void Disk::readBootCode() throw(Exception) {
 
 	try {
 		fstr.seekg(0, std::ios_base::beg);
-		fstr.read(this->_bootCode, 440);
+		fstr.read(this->_bootCode, Doclone::MBR_SIZE);
 		fstr.close();
 
 	}catch(...) {
@@ -112,7 +120,7 @@ void Disk::readBootCode() throw(Exception) {
 }
 
 /**
- * \brief Writes the first 440 bytes of the disk
+ * \brief Writes the first Doclone::MBR_SIZE bytes of the disk
  */
 void Disk::writeBootCode() const throw(Exception) {
 	Logger *log = Logger::getInstance();
@@ -127,7 +135,7 @@ void Disk::writeBootCode() const throw(Exception) {
 
 	try {
 		fstr.seekp(0, std::ios_base::beg);
-		fstr.write(this->_bootCode, 440);
+		fstr.write(this->_bootCode, Doclone::MBR_SIZE);
 		fstr.close();
 
 	}catch(...) {
@@ -148,22 +156,22 @@ void Disk::writeBootCode() const throw(Exception) {
 void Disk::readPartitions() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Disk::readPartitions() start");
-	
+
 	this->_partitions.clear();
-	
+
 	PedPartition *pedPart = 0;
-	
+
 	PartedDevice *pedDev = PartedDevice::getInstance();
 	pedDev->open();
 	PedDisk *pDisk = pedDev->getDisk();
-	
+
 	while ((pedPart = ped_disk_next_partition (pDisk, pedPart))) {
 		if (ped_partition_is_active (pedPart)) {
 			try {
 				std::string path=
 						Util::buildPartPath(pedPart->disk->dev->path, pedPart->num);
-				// These Partition objects will be destroyed in Image::~Image()
-				Partition *part = new Partition (path);
+				Partition *part = new Partition();
+				part->initFromPath(path);
 				this->_partitions.push_back(part);
 			}
 			catch(const WarningException &ex) {
@@ -171,9 +179,9 @@ void Disk::readPartitions() throw(Exception) {
 			}
 		}
 	}
-	
+
 	pedDev->close();
-	
+
 	log->debug("Disk::readPartitions() end");
 }
 
@@ -217,28 +225,34 @@ PedGeometry *Disk::calcGeometry(const PedDisk* pDisk,const Partition *part)
 	 * Libdoclone aligns partitions to MiB, aligning them also to sectors of
 	 * 4096 bytes.
 	 *
-	 * This variable contains the amount of sectors that fit on a MiB for this
+	 * This variable contains the amount of sectors that fits on a MiB for this
 	 * disk.
 	 */
 	PedSector mibAlignedMultiple=(1024*1024)/pDisk->dev->sector_size;
 
 	double usedPart = part->getUsedPart();
 	double startPos = part->getStartPos();
-	
+
 	PedSector startSector = (pDisk->dev->length * startPos);
 	PedSector endSector = startSector + (pDisk->dev->length * usedPart);
 
-	// The partition begins in the next sector aligned to MiB
-	startSector += (mibAlignedMultiple-(startSector % mibAlignedMultiple));
+	// If the start sector is not aligned to MiB
+	if((startSector % mibAlignedMultiple)!=0) {
+		// The partition begins in the next sector aligned to MiB
+		startSector += (mibAlignedMultiple-(startSector % mibAlignedMultiple));
+	}
 
-	// The end is also aligned as possible
-	endSector += (mibAlignedMultiple-(endSector % mibAlignedMultiple));
+	//If the end sector is not aligned to MiB
+	if((endSector % mibAlignedMultiple)!=0) {
+		// The end is also aligned as possible
+		endSector += (mibAlignedMultiple-(endSector % mibAlignedMultiple));
+	}
 
 	// If a partition starts before the first MiB, must be moved.
 	if(startSector<mibAlignedMultiple) {
 		startSector = mibAlignedMultiple;
 	}
-	
+
 	// If one partition exceeds the end of the disk, must be cut.
 	if(endSector > pDisk->dev->length) {
 		endSector = pDisk->dev->length;
@@ -298,9 +312,14 @@ PedConstraint *Disk::calcConstraint(const PedPartition* pPart,
 
 	PedConstraint *pConstraint = ped_constraint_new(startAlign, endAlign,
 			startRange, endRange, minSize, maxSize);
-		
+
+	ped_geometry_destroy(startRange);
+	ped_geometry_destroy(endRange);
+	ped_alignment_destroy(startAlign);
+	ped_alignment_destroy(endAlign);
+
 	log->debug("Disk::calcConstraint(pedGeom=>0x%x) end", pConstraint);
-	
+
 	return pConstraint;
 }
 
@@ -319,7 +338,7 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 	PedPartition *pedPart = 0 ;
 	PedConstraint *constraint = 0 ;
 	PedFileSystemType* fsType = 0 ;
-	
+
 	PartedDevice *pedDev = PartedDevice::getInstance();
 	pedDev->open();
 	PedDisk *pDisk = pedDev->getDisk();
@@ -336,7 +355,7 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 		case Doclone::PARTITION_EXTENDED: {
 			type = PED_PARTITION_EXTENDED ;
 			break ;
-		}	
+		}
 		default	:
 			type = PED_PARTITION_FREESPACE;
 			break;
@@ -351,10 +370,10 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 
 	if (pedPart) {
 		constraint = this->calcConstraint(pedPart, part->getMinSize());
-		
-		if ( constraint ) {
-	
-			if ( ped_disk_add_partition(pDisk, pedPart, constraint )) {
+
+		if (constraint) {
+
+			if (ped_disk_add_partition(pDisk, pedPart, constraint)) {
 				pedDev->commit();
 			}
 			else {
@@ -368,7 +387,7 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 				 */
 				constraint = ped_constraint_any(pDisk->dev);
 
-				if ( ped_disk_add_partition(pDisk, pedPart, constraint )) {
+				if (ped_disk_add_partition(pDisk, pedPart, constraint)) {
 					pedDev->commit();
 				} else {
 					// I give up
@@ -376,12 +395,12 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 					throw exc;
 				}
 			}
-			
+
 			// Set the new partition number and path
 			part->setPartNum(pedPart->num);
 			part->setPath(Util::buildPartPath(this->_path, pedPart->num));
-			
-			ped_constraint_destroy( constraint );
+
+			ped_constraint_destroy(constraint);
 		}
 	} else {
 		CreatePartitionException ex;
@@ -390,6 +409,8 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 
 	pedDev->close();
 
+	ped_geometry_destroy(geom);
+
 	log->debug("Disk::writePartitionToDisk() end");
 }
 
@@ -399,9 +420,9 @@ void Disk::writePartitionToDisk(Partition *part) const throw(Exception) {
 void Disk::writePartitions() const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Disk::writePartitions() start");
-	
+
 	this->makeLabel();
-	
+
 	Clone *dcl = Clone::getInstance();
 	dcl->markCompleted(Doclone::OP_MAKE_DISKLABEL, this->_path);
 
@@ -414,11 +435,16 @@ void Disk::writePartitions() const throw(Exception) {
 
 		this->writePartitionToDisk(part);
 
+		if(part->getType() != Doclone::PARTITION_EXTENDED) {
+			//Remove old superblocks and signatures if any
+			part->clearSignatures();
+		}
+
 		std::stringstream target;
 		target << this->_path << ", #" << (i+1);
 		dcl->markCompleted(Doclone::OP_CREATE_PARTITION, target.str());
 	}
-	
+
 	log->debug("Disk::writePartitions() end");
 }
 
@@ -443,6 +469,10 @@ void Disk::restoreGrub() throw(Exception) {
  * \brief Clears the partitions vector
  */
 Disk::~Disk() {
+	for(unsigned int i=0; i<this->_partitions.size(); i++) {
+		Partition *part = this->_partitions.at(i);
+		delete part;
+	}
 	this->_partitions.clear();
 }
 
