@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 namespace Doclone {
 
-DiskLabel::DiskLabel(const std::string &path) : Disk(path), _labelType(),
+DiskLabel::DiskLabel() : _labelType(),
 		_partedName() {
 }
 
@@ -31,6 +31,10 @@ Doclone::diskLabelType DiskLabel::getLabelType() const {
 	return this->_labelType;
 }
 
+void DiskLabel::setLabelType(Doclone::diskLabelType labelType) {
+	this->_labelType = labelType;
+}
+
 /**
  * \brief Writes a new disk label in the current disk
  */
@@ -53,6 +57,11 @@ void DiskLabel::makeLabel() const throw(Exception) {
 			throw ex;
 		}
 
+		PedDisk *oldpDisk = pedDev->getDisk();
+		if(oldpDisk) {
+			ped_disk_destroy(oldpDisk);
+		}
+
 		pedDev->setDisk(pDisk);
 		pedDev->commit();
 	}
