@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,12 +19,20 @@
 #include <doclone/Filesystem.h>
 
 #include <string.h>
+#include <sys/types.h>
+#include <dirent.h>
 
 #include <string>
 
 #include <blkid/blkid.h>
 
 #include <doclone/Logger.h>
+#include <doclone/DataTransfer.h>
+#include <doclone/Util.h>
+#include <doclone/exception/ReadDataException.h>
+#include <doclone/exception/FileNotFoundException.h>
+#include <doclone/exception/ReadErrorsInDirectoryException.h>
+#include <doclone/exception/WriteErrorsInDirectoryException.h>
 
 namespace Doclone {
 
@@ -70,6 +78,12 @@ const std::string &Filesystem::getCommand() const {
 const std::string &Filesystem::getFormatOptions() const {
 	return this->_formatOptions;
 }
+const std::string &Filesystem::getLabel() const {
+	return this->_label;
+}
+const std::string &Filesystem::getUUID() const {
+	return this->_uuid;
+}
 bool Filesystem::getMountSupport() const {
 	return this->_mountSupport;
 }
@@ -82,12 +96,6 @@ bool Filesystem::getUUIDSupport() const {
 bool Filesystem::getLabelSupport() const {
 	return this->_labelSupport;
 }
-const std::string &Filesystem::getMountPoint() const {
-	return this->_mountPoint;
-}
-void Filesystem::setMountPoint(const std::string &path) {
-	this->_mountPoint = path;
-}
 
 /**
  * \brief Reads a filesystem label by using libblkid
@@ -95,31 +103,31 @@ void Filesystem::setMountPoint(const std::string &path) {
  * \param dev
  * 		The path of the device where filesystem is
  */
-std::string Filesystem::readLabel(const std::string &dev) const throw(Exception) {
+void Filesystem::readLabel(const std::string &dev) throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Filesystem::readLabel(dev=>%s) start", dev.c_str());
 
-	std::string label;
 	const char *type, *value;
 	blkid_cache cache = 0;
 
 	blkid_get_cache(&cache, "/dev/null"); //Do not use blkid cache
 	blkid_dev blDev = blkid_get_dev(cache, dev.c_str(), BLKID_DEV_NORMAL);
 	if(!blDev) {
-		return "";
+		blkid_put_cache(cache);
+		log->debug("Filesystem::readLabel(label=>) end");
+		return;
 	}
 	blkid_tag_iterate iter = blkid_tag_iterate_begin(blDev);
 
 	while (blkid_tag_next(iter, &type, &value) == 0) {
 		if (!strcmp(type, "LABEL")) {
-			label = value;
+			this->_label = value;
 		}
 	}
 	blkid_tag_iterate_end(iter);
 	blkid_put_cache(cache);
 
-	log->debug("Filesystem::readLabel(label=>%s) end", label.c_str());
-	return label;
+	log->debug("Filesystem::readLabel() end");
 }
 
 /**
@@ -128,32 +136,31 @@ std::string Filesystem::readLabel(const std::string &dev) const throw(Exception)
  * \param dev
  * 		The path of the device where filesystem is
  */
-std::string Filesystem::readUUID(const std::string &dev) const throw(Exception) {
+void Filesystem::readUUID(const std::string &dev) throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Filesystem::readUUID(dev=>%s) start", dev.c_str());
 
-	std::string uuid;
 	const char *type, *value;
 	blkid_cache cache = 0;
 
 	blkid_get_cache(&cache, "/dev/null"); //Do not use blkid cache
 	blkid_dev blDev = blkid_get_dev(cache, dev.c_str(), BLKID_DEV_NORMAL);
 	if(!blDev) {
+		blkid_put_cache(cache);
 		log->debug("Filesystem::readUUID(uuid=>) end");
-		return "";
+		return;
 	}
 	blkid_tag_iterate iter = blkid_tag_iterate_begin(blDev);
 
 	while (blkid_tag_next(iter, &type, &value) == 0) {
 		if (!strcmp(type, "UUID")) {
-			uuid = value;
+			this->_uuid = value;
 		}
 	}
 	blkid_tag_iterate_end(iter);
 	blkid_put_cache(cache);
 
-	log->debug("Filesystem::readUUID(uuid=>%s) end", uuid.c_str());
-	return uuid;
+	log->debug("Filesystem::readUUID() end");
 }
 
 }
