@@ -39,7 +39,7 @@ namespace Doclone {
  * \param disk
  * 		The disk on which we will work
  */
-Grub::Grub(const Disk *disk) throw(Exception) : _disk(disk) {
+Grub::Grub(Disk *disk) throw(Exception) : _disk(disk) {
 	// Formatting support
 	if(Util::find_program_in_path(GRUB_COMMAND).empty()) {
 		GrubException ex;
@@ -76,10 +76,10 @@ void Grub::searchPartition() throw(Exception) {
 			part->doMount();
 
 			try {
-				std::string bootGrubPath = part->getFileSystem()->getMountPoint();
+				std::string bootGrubPath = part->getMountPoint();
 				bootGrubPath.append("/boot/grub");
 
-				std::string grubPath = part->getFileSystem()->getMountPoint();
+				std::string grubPath = part->getMountPoint();
 				grubPath.append("/grub");
 
 				std::ifstream bootGrubDir(bootGrubPath.c_str());
@@ -104,7 +104,7 @@ void Grub::searchPartition() throw(Exception) {
 			continue;
 		}
 	}
-	
+
 	log->debug("Grub::searchPartition() end");
 }
 
@@ -114,14 +114,14 @@ void Grub::searchPartition() throw(Exception) {
 void Grub::install() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Grub::install() start");
-	
+
 	int exitValue=-1;
-	
+
 	if(this->_grubParts.empty()) {
 		GrubException ex;
 		throw ex;
 	}
-	
+
 	// In the no-data mode, it is not possible to install GRUB
 	Clone *dcl = Clone::getInstance();
 	if(dcl->getEmpty() == true) {
@@ -150,7 +150,7 @@ void Grub::install() throw(Exception) {
 
 				grub_install_cmdline = GRUB_COMMAND;
 				grub_install_cmdline.append(" -d ");
-				grub_install_cmdline.append(part->getFileSystem()->getMountPoint());
+				grub_install_cmdline.append(part->getMountPoint());
 				grub_install_cmdline.append(it->second);
 				grub_install_cmdline.append(" ");
 				grub_install_cmdline.append(this->_disk->getPath());
@@ -171,16 +171,16 @@ void Grub::install() throw(Exception) {
 			continue;
 		}
 	}
-	
+
 	if (exitValue<0) {
 		GrubException ex;
 		throw ex;
 	}
-	
+
 	dcl->markCompleted(Doclone::OP_GRUB_INSTALL,
 			this->_disk->getPath());
 
 	log->debug("Grub::install() end");
 }
-	
+
 }
