@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,9 +44,27 @@
 #include <doclone/exception/NoBlockDeviceException.h>
 #include <doclone/exception/CreateImageException.h>
 #include <doclone/exception/RestoreImageException.h>
+#include <doclone/exception/CloseConnectionException.h>
 
 namespace Doclone {
 
+/**
+ * \brief Initializes attributes
+ */
+Link::Link(): _fdin(), _fdout(), _dstIP() {
+	Clone *dcl = Clone::getInstance();
+
+	unsigned int nodes = dcl->getNodesNumber();
+	if(nodes == 0) {
+		this->_linksNum = Doclone::LINKS_NUM;
+	}
+	else {
+		this->_linksNum = nodes;
+	}
+
+	this->_interface = dcl->getInterface();
+}
+
 /**
  * \brief Establishes a communication with the sender via UDP to inform it
  * that this node is available to receive data.
@@ -59,7 +77,7 @@ namespace Doclone {
 int Link::answer() const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Link::answer() start");
-	
+
 	int sock_udp;
 	uint32_t next_link;
 	sockaddr_in udp = {};
@@ -78,14 +96,18 @@ int Link::answer() const throw(Exception) {
 		ConnectionException ex;
 		throw ex;
 	}
-	
+
 	u_int loop = 0;
 	setsockopt(sock_udp, IPPROTO_IP, IP_MULTICAST_LOOP, &loop, sizeof(loop));
 
 	// We join the broadcast group
 	ip_mreq mReq;
 	mReq.imr_multiaddr.s_addr = inet_addr (Doclone::MULTICAST_GROUP);
-	mReq.imr_interface.s_addr = htonl(INADDR_ANY);
+	if(this->_interface.compare("")==0) {
+		mReq.imr_interface.s_addr = htonl(INADDR_ANY);
+	} else {
+		mReq.imr_interface.s_addr =  inet_addr(this->_interface.c_str());
+	}
 
 	setsockopt (sock_udp, IPPROTO_IP, IP_ADD_MEMBERSHIP, &mReq, sizeof(mReq));
 
@@ -155,10 +177,11 @@ int Link::answer() const throw(Exception) {
 int Link::netScan() const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Link::netScan() start");
-	
+
 	int sock_udp;
 	fd_set readSet;
 	in_addr_t links[this->_linksNum];
+	struct in_addr localInterface = {};
 	sockaddr_in udp = {};
 	timeval timeout = { 3, 0 };
 	socklen_t addrlen = sizeof (sockaddr);
@@ -172,6 +195,11 @@ int Link::netScan() const throw(Exception) {
 	udp.sin_port = htons (Doclone::PORT_PING);
 	udp.sin_addr.s_addr = inet_addr (Doclone::MULTICAST_GROUP);
 
+	if(this->_interface.compare("")!=0) {
+		localInterface.s_addr = inet_addr (this->_interface.c_str());
+		setsockopt(sock_udp, IPPROTO_IP, IP_MULTICAST_IF, (char *)&localInterface, sizeof(localInterface));
+	}
+
 	dcCommand request = Doclone::C_LINK_SERVER_OK;
 	if ((sendto (sock_udp, &request, sizeof(request), 0,
 			reinterpret_cast<sockaddr*>(&udp), addrlen)) < 0) {
@@ -181,7 +209,7 @@ int Link::netScan() const throw(Exception) {
 
 	FD_ZERO (&readSet);
 	FD_SET (sock_udp, &readSet);
-	
+
 	unsigned int i = 0;
 	while (select (sock_udp + 1, &readSet, 0, 0, &timeout) > 0) {
 		if(FD_ISSET(sock_udp, &readSet)) {
@@ -247,28 +275,29 @@ int Link::netScan() const throw(Exception) {
 void Link::linkServer() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Link::linkServer() start");
-	
+
 	sockaddr_in host_receiver;
 	socklen_t size = sizeof (sockaddr);
-	DataTransfer *trns = DataTransfer::getInstance();
 
 	host_receiver.sin_family = AF_INET;
 	host_receiver.sin_port = htons (Doclone::PORT_DATA);
 	host_receiver.sin_addr.s_addr = this->netScan();
 
-	int fd;
-	if ((fd = socket (AF_INET, SOCK_STREAM, 0)) < 0) {
+	int fdd;
+	if ((fdd = socket (AF_INET, SOCK_STREAM, 0)) < 0) {
 		ConnectionException ex;
 		throw ex;
 	}
 	sleep (1);
 
-	if ((connect (fd, reinterpret_cast<sockaddr*>(&host_receiver), size)) < 0) {
+	if ((connect (fdd, reinterpret_cast<sockaddr*>(&host_receiver), size)) < 0) {
 		ConnectionException ex;
 		throw ex;
 	}
-	
-	trns->setFdd(fd, inet_ntoa (host_receiver.sin_addr));
+
+	// Set the destination descriptor
+	this->_fdout = fdd;
+	this->_dstIP = inet_ntoa (host_receiver.sin_addr);
 
 	log->debug("Link::linkServer() end");
 }
@@ -280,14 +309,13 @@ void Link::linkServer() throw(Exception) {
 void Link::linkClient() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Link::linkClient() start");
-	
-	int fdo;
+
+	int fdi;
 	int ip_next_link;
 	int sock_sender;
 	sockaddr_in host_sender;
 	sockaddr_in host_receiver;
 	socklen_t size = sizeof (sockaddr);
-	DataTransfer *trns = DataTransfer::getInstance();
 
 	ip_next_link = this->answer();
 
@@ -315,8 +343,8 @@ void Link::linkClient() throw(Exception) {
 		ConnectionException ex;
 		throw ex;
 	}
-	
-	if ((fdo=
+
+	if ((fdi=
 		 accept (sock_sender,
 				 reinterpret_cast<sockaddr*>(&host_sender), &size)) < 0) {
 		ConnectionException ex;
@@ -324,7 +352,7 @@ void Link::linkClient() throw(Exception) {
 	}
 
 	// Set the origin descriptor
-	trns->setFdo(fdo);
+	this->_fdin = fdi;
 	this->_srcIP = inet_ntoa (host_sender.sin_addr);
 
 	// Notify the views
@@ -352,11 +380,11 @@ void Link::linkClient() throw(Exception) {
 			throw ex;
 		}
 
-		// Set the destiny descriptor
-		trns->setFdd(fdd, inet_ntoa (host_receiver.sin_addr));
+		// Set the destination descriptor and IP
+		this->_fdout = fdd;
+		this->_dstIP = inet_ntoa (host_receiver.sin_addr);
 	}
-	
-	
+
 	log->debug("Link::linkClient() end");
 }
 
@@ -366,14 +394,9 @@ void Link::linkClient() throw(Exception) {
  * \param image
  * 		The path of the image
  */
-void Link::sendFromImage(const std::string &image) throw(Exception) {
+void Link::sendFromImage() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Link::sendFromImage(image=>%s) start", image.c_str());
-
-	uint64_t totalSize = Util::getFileSize(image);
-
-	DataTransfer *trns = DataTransfer::getInstance();
-	trns->setTotalSize(totalSize);
+	log->debug("Link::sendFromImage() start");
 
 	Operation *waitOp = new Operation(
 			Doclone::OP_WAIT_CLIENTS, "");
@@ -385,7 +408,7 @@ void Link::sendFromImage(const std::string &image) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_CLIENTS, "");
 
-	int fd = Util::openFile(image);
+	int fd = Util::openFile(this->_image);
 
 	Operation *transferOp = new Operation(
 			Doclone::OP_TRANSFER_DATA, "");
@@ -398,10 +421,15 @@ void Link::sendFromImage(const std::string &image) throw(Exception) {
 	 * If the system is little-endian, it's necessary to convert totalSize to
 	 * big-endian.
 	 */
-	uint64_t tmpTotalSize = htobe64(totalSize);
-	trns->transferFrom(&tmpTotalSize, static_cast<size_t>(sizeof(uint64_t)));
+	uint64_t totalSize = this->getImageSize(fd);
+	DataTransfer *trns = DataTransfer::getInstance();
+	trns->setTotalSize(totalSize);
 
-	trns->transferAllFrom(fd);
+	uint64_t tmpTotalSize = htobe64(totalSize);
+	DataTransfer::sendData(this->_fdout, &tmpTotalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
+
+	trns->copyData(fd, this->_fdout);
 
 	dcl->markCompleted(Doclone::OP_TRANSFER_DATA, "");
 
@@ -418,12 +446,12 @@ void Link::sendFromImage(const std::string &image) throw(Exception) {
  * \param device
  * 		The path of the device
  */
-void Link::sendFromDevice(const std::string &device) throw(Exception) {
+void Link::sendFromDevice() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Link::sendFromDevice(device=>%s) start", device.c_str());
+	log->debug("Link::sendFromDevice() start");
 
 	PartedDevice *pedDev = PartedDevice::getInstance();
-	pedDev->initialize(Util::getDiskPath(device));
+	pedDev->initialize(Util::getDiskPath(this->_device));
 
 	Operation *waitOp = new Operation(
 			Doclone::OP_WAIT_CLIENTS, "");
@@ -435,17 +463,16 @@ void Link::sendFromDevice(const std::string &device) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_CLIENTS, "");
 
-	if(!Util::isBlockDevice(device)) {
+	if(!Util::isBlockDevice(this->_device)) {
 		NoBlockDeviceException ex;
 		throw ex;
 	}
 
 	PartedDevice *pDevice = PartedDevice::getInstance();
 	std::string target = pDevice->getPath();
-	Disk *dcDisk = DlFactory::createDiskLabel();
 	Image image;
 
-	if(Util::isDisk(device)) {
+	if(Util::isDisk(this->_device)) {
 		image.setType(Doclone::IMAGE_DISK);
 	}
 	else {
@@ -457,7 +484,7 @@ void Link::sendFromDevice(const std::string &device) throw(Exception) {
 
 	dcl->addOperation(readPartTableOp);
 
-	image.readPartitionTable(device);
+	image.readPartitionTable(this->_device);
 
 	// Mark the operation to read partition table as completed
 	dcl->markCompleted(Doclone::OP_READ_PARTITION_TABLE, target);
@@ -468,8 +495,8 @@ void Link::sendFromDevice(const std::string &device) throw(Exception) {
 	}
 
 	image.initCreateOperations();
-
-	image.createImageHeader(dcDisk);
+	image.initDiskReadArchive();
+	image.initFdWriteArchive(this->_fdout);
 
 	/*
 	 * Before sending the data, it sends its size. So the client/s can
@@ -477,17 +504,27 @@ void Link::sendFromDevice(const std::string &device) throw(Exception) {
 	 * If the system is little-endian, it's necessary to convert totalSize to
 	 * big-endian.
 	 */
+	Disk *disk = image.getDisk();
+	uint8_t numPartitions = disk->getPartitions().size();
+	uint64_t tmpTotalSize = 0;
+	for(int i = 0;i<numPartitions;i++) {
+		tmpTotalSize += disk->getPartitions().at(i)->getMinSize();
+	}
 	DataTransfer *trns = DataTransfer::getInstance();
-	uint64_t tmpTotalSize = htobe64(image.getHeader().image_size);
-	trns->transferFrom(&tmpTotalSize, static_cast<size_t>(sizeof(uint64_t)));
+	trns->setTotalSize(tmpTotalSize);
 
-	image.writeImageHeader();
+	tmpTotalSize = htobe64(tmpTotalSize);
+	DataTransfer::sendData(this->_fdout, &tmpTotalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
+
+	image.saveImageHeader();
 
 	image.readPartitionsData();
 
-	this->closeConnection();
+	image.freeWriteArchive();
+	image.freeReadArchive();
 
-	delete dcDisk;
+	this->closeConnection();
 
 	log->debug("Link::sendFromDevice() end");
 }
@@ -498,14 +535,14 @@ void Link::sendFromDevice(const std::string &device) throw(Exception) {
 void Link::send() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Link::send() start");
-	
+
 	Clone *dcl = Clone::getInstance();
 
 	try {
 		if(dcl->getDevice().empty()) {
-			this->sendFromImage(dcl->getImage());
+			this->sendFromImage();
 		} else {
-			this->sendFromDevice(dcl->getDevice());
+			this->sendFromDevice();
 		}
 	} catch (const CancelException &ex) {
 		this->closeConnection();
@@ -530,9 +567,9 @@ void Link::send() throw(Exception) {
  * \param image
  * 		The path of the image
  */
-void Link::receiveToImage(const std::string &image) throw(Exception) {
+void Link::receiveToImage() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Link::receiveToImage(image=>%s) start", image.c_str());
+	log->debug("Link::receiveToImage() start");
 
 	DataTransfer *trns = DataTransfer::getInstance();
 
@@ -546,16 +583,24 @@ void Link::receiveToImage(const std::string &image) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_SERVER, "");
 
-	Util::createFile(image);
-	int fd = Util::openFile(image);
+	Util::createFile(this->_image);
+	int fd = Util::openFile(this->_image);
 
 	Operation *transferOp = new Operation(
 			Doclone::OP_TRANSFER_DATA, "");
 
 	dcl->addOperation(transferOp);
 
+	// Receive the total amount of bytes to be transferred
 	uint64_t totalSize;
-	trns->transferTo(&totalSize, static_cast<size_t>(sizeof(uint64_t)));
+	DataTransfer::recvData(this->_fdin, &totalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
+
+	// Pass it to the next link if any
+	if(this->_fdout != 0) {
+		DataTransfer::sendData(this->_fdout, &totalSize,
+				static_cast<size_t>(sizeof(uint64_t)));
+	}
 
 	/*
 	 * The given totalSize is received in big-endian. If the system is
@@ -564,7 +609,12 @@ void Link::receiveToImage(const std::string &image) throw(Exception) {
 	uint64_t tmpTotalSize = be64toh(totalSize);
 	trns->setTotalSize(tmpTotalSize);
 
-	trns->transferAllTo(fd);
+	std::vector<int> fdsOut;
+	fdsOut.push_back(fd);
+	if(this->_fdout != 0) {
+		fdsOut.push_back(this->_fdout);
+	}
+	trns->copyData(this->_fdin, fdsOut);
 
 	dcl->markCompleted(Doclone::OP_TRANSFER_DATA, "");
 
@@ -581,12 +631,12 @@ void Link::receiveToImage(const std::string &image) throw(Exception) {
  * \param device
  * 		The path of the device
  */
-void Link::receiveToDevice(const std::string &device) throw(Exception) {
+void Link::receiveToDevice() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Link::receiveToDevice(device=>%s) start", device.c_str());
+	log->debug("Link::receiveToDevice() start");
 
 	PartedDevice *pedDev = PartedDevice::getInstance();
-	pedDev->initialize(Util::getDiskPath(device));
+	pedDev->initialize(Util::getDiskPath(this->_device));
 
 	Operation *waitOp = new Operation(
 			Doclone::OP_WAIT_SERVER, "");
@@ -598,51 +648,52 @@ void Link::receiveToDevice(const std::string &device) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_SERVER, "");
 
-	if(!Util::isBlockDevice(device)) {
+	if(!Util::isBlockDevice(this->_device)) {
 		NoBlockDeviceException ex;
 		throw ex;
 	}
 
+	// Receive the total amount of bytes to be transferred
 	uint64_t totalSize;
-	DataTransfer *trns = DataTransfer::getInstance();
-	trns->transferTo(&totalSize, static_cast<size_t>(sizeof(uint64_t)));
+	DataTransfer::recvData(this->_fdin, &totalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
+
+	// Pass it to the next link if any
+	if(this->_fdout != 0) {
+		DataTransfer::sendData(this->_fdout, &totalSize,
+				static_cast<size_t>(sizeof(uint64_t)));
+	}
 
 	/*
 	 * The given totalSize is received in big-endian. If the system is
 	 * little-endian, it must be converted to little-endian.
 	 */
 	uint64_t tmpTotalSize = be64toh(totalSize);
+	DataTransfer *trns = DataTransfer::getInstance();
 	trns->setTotalSize(tmpTotalSize);
 
 	Image image;
+	image.initFdReadArchive(this->_fdin);
+	image.initDiskWriteArchive();
 
-	image.readImageHeader(device);
+	image.loadImageHeader();
 
-	image.openImageHeader();
-
-	Disk *dcDisk = DlFactory::createDiskLabel(image.getLabelType(),
-			pedDev->getPath());
-
-	if(image.canRestoreCheck(device, dcDisk->getSize()) == false) {
+	if(image.canRestoreCheck(this->_device) == false) {
 		RestoreImageException ex;
 		throw ex;
 	}
 
-	image.initRestoreOperations(device);
+	image.initRestoreOperations(this->_device);
 
-	image.writePartitionTable(device);
+	image.writePartitionTable(this->_device);
 
-	image.writePartitionsData();
+	image.writePartitionsData(this->_device);
 
-	if(image.getHeader().image_type==(Doclone::imageType)IMAGE_DISK) {
-		dcDisk->setPartitions(image.getPartitions());
-		dcDisk->restoreGrub();
-	}
+	image.freeWriteArchive();
+	image.freeReadArchive();
 
 	this->closeConnection();
 
-	delete dcDisk;
-
 	log->debug("Link::receiveToDevice() end");
 }
 
@@ -654,12 +705,12 @@ void Link::receive() throw(Exception) {
 	log->debug("Link::receive() start");
 
 	Clone *dcl = Clone::getInstance();
-	
+
 	try {
 		if(dcl->getDevice().empty()) {
-			this->receiveToImage(dcl->getImage());
+			this->receiveToImage();
 		} else {
-			this->receiveToDevice(dcl->getDevice());
+			this->receiveToDevice();
 		}
 	} catch (const CancelException &ex) {
 		this->closeConnection();
@@ -678,4 +729,28 @@ void Link::receive() throw(Exception) {
 	log->debug("Link::receive() end");
 }
 
+/**
+ * \brief Closes the opened connections
+ */
+void Link::closeConnection() throw(Exception) {
+	Logger *log = Logger::getInstance();
+	log->debug("Link::closeConnection() start");
+
+	if(this->_fdin) {
+		if(close(this->_fdin)<0) {
+			CloseConnectionException ex;
+			ex.logMsg();
+		}
+	}
+
+	if(this->_fdout) {
+		if(close(this->_fdout)<0) {
+			CloseConnectionException ex;
+			ex.logMsg();
+		}
+	}
+
+	log->debug("Link::closeConnection() end");
+}
+
 }
