@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 #include <doclone/Logger.h>
 #include <doclone/exception/CommitException.h>
+#include <doclone/exception/NoAccessToDeviceException.h>
 
 namespace Doclone {
 
@@ -39,7 +40,17 @@ PartedDevice::PartedDevice(): _openings(0), _path(), _pDevice(0), _pDisk(0) {
  * \brief Closes the opened device
  */
 PartedDevice::~PartedDevice() {
-	this->close();
+
+	if(this->_pDisk) {
+		ped_disk_destroy( this->_pDisk );
+		this->_pDisk = 0;
+	}
+
+	if(this->_pDevice) {
+		ped_device_destroy( this->_pDevice );
+		this->_pDevice = 0;
+	}
+
 	this->_openings = 0;
 }
 
@@ -72,6 +83,10 @@ PedDisk *PartedDevice::getDisk() {
 	return this->_pDisk;
 }
 
+PedPartition *PartedDevice::getPartition(unsigned int numPartition) const {
+	return ped_disk_get_partition(this->_pDisk, numPartition);
+}
+
 void PartedDevice::setDisk(PedDisk *pDisk) {
 	this->_pDisk = pDisk;
 }
@@ -84,13 +99,29 @@ void PartedDevice::setDisk(PedDisk *pDisk) {
 uint64_t PartedDevice::getDevSize() const {
 	Logger *log = Logger::getInstance();
 	log->debug("PartedDevice::getDevSize() start");
-	
+
 	uint64_t devSize=(this->_pDevice->length * this->_pDevice->sector_size);
-	
+
 	log->debug("PartedDevice::getDevSize(devSize=>%d) end", devSize);
 	return devSize;
 }
 
+/**
+ * \brief Gets the size of the given partition in the opened device
+ *
+ * \return Size in bytes
+ */
+uint64_t PartedDevice::getPartitionSize(unsigned int numPartition) const {
+	Logger *log = Logger::getInstance();
+	log->debug("PartedDevice::getPartitionSize(numPartition=>%d) start", numPartition);
+
+	PedPartition *pPart = this->getPartition(numPartition);
+	uint64_t devSize=(pPart->geom.length * this->_pDevice->sector_size);
+
+	log->debug("PartedDevice::getPartitionSize(devSize=>%d) end", devSize);
+	return devSize;
+}
+
 /**
  * \brief Sets the disk which will be opened
  */
@@ -99,7 +130,7 @@ void PartedDevice::initialize(const std::string &device) {
 	log->debug("PartedDevice::initialize(device=>%s) start", device.c_str());
 
 	this->_path = device;
-	
+
 	log->debug("PartedDevice::initialize() end");
 }
 
@@ -108,20 +139,35 @@ void PartedDevice::initialize(const std::string &device) {
  *
  * If it is opened, don't make anything.
  */
-void PartedDevice::open() {
+void PartedDevice::open() throw(Exception){
 	Logger *log = Logger::getInstance();
 	log->debug("PartedDevice::open() start");
-	
+
+	if(this->_openings > 0) {
+		this->_openings++;
+		return;
+	}
+
 	if(!this->_pDevice) {
-		this->_pDevice = ped_device_get( this->_path.c_str() );
+		this->_pDevice = ped_device_get( this->_path.c_str());
+
+		if(!this->_pDevice) {
+			NoAccessToDeviceException ex(this->_path);
+			throw ex;
+		}
+
+		if(!ped_device_open(this->_pDevice)) {
+			NoAccessToDeviceException ex(this->_path);
+			throw ex;
+		}
 	}
-	
+
 	if(!this->_pDisk) {
-		this->_pDisk = ped_disk_new( this->_pDevice  );
+		this->_pDisk = ped_disk_new(this->_pDevice);
 	}
-	
-	this->_openings++;
-	
+
+	this->_openings =1 ;
+
 	log->debug("PartedDevice::open() end");
 }
 
@@ -133,46 +179,47 @@ void PartedDevice::open() {
 void PartedDevice::close() {
 	Logger *log = Logger::getInstance();
 	log->debug("PartedDevice::close() start");
-	
+
 	if(this->_openings>1) {
 		this->_openings--;
 		return;
 	}
-	
+
 	if(this->_pDisk) {
-		ped_disk_destroy( this->_pDisk );
+		ped_disk_destroy(this->_pDisk);
 		this->_pDisk = 0;
 	}
-	
+
 	if(this->_pDevice) {
-		ped_device_destroy( this->_pDevice );
+		ped_device_close(this->_pDevice);
+		ped_device_destroy(this->_pDevice);
 		this->_pDevice = 0;
 	}
-	
+
 	this->_openings = 0;
-	
+
 	log->debug("PartedDevice::close() end");
 }
 
 /**
  * \brief Commits the changes to disk.
  */
-void PartedDevice::commit() const {
+void PartedDevice::commit() const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("PartedDevice::commit() start");
-	
+
 	if(!ped_disk_commit_to_dev(this->_pDisk)) {
 		CommitException ex;
 		throw ex;
 	}
-	
+
 	int i = 0;
 
 	// Wait up to 30 seconds if the device is busy
 	while(!ped_disk_commit_to_os (this->_pDisk)) {
 		if (errno == EBUSY) {
 			if(i<30) {
-				 // Device busy, wait one more second
+				 // Device busy, let's wait one more second
 				sleep(1);
 				i++;
 				continue;
@@ -189,7 +236,7 @@ void PartedDevice::commit() const {
 			throw ex;
 		}
 	}
-	
+
 	log->debug("PartedDevice::commit() end");
 }
 
