@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,9 +43,27 @@
 #include <doclone/exception/CreateImageException.h>
 #include <doclone/exception/RestoreImageException.h>
 #include <doclone/exception/CancelException.h>
+#include <doclone/exception/CloseConnectionException.h>
 
 namespace Doclone {
 
+/**
+ * \brief Default constructor.
+ *
+ * Initializes attributes.
+ */
+Unicast::Unicast(): _fds() {
+	Clone *dcl = Clone::getInstance();
+
+	unsigned int nodes = dcl->getNodesNumber();
+	if(nodes == 0) {
+		this->_nodesNum = 1;
+	}
+	else {
+		this->_nodesNum = nodes;
+	}
+}
+
 /**
  * \brief This function is called by the server and waits for a connection from
  * the receivers.
@@ -55,11 +73,10 @@ namespace Doclone {
 void Unicast::tcpServer() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Unicast::tcpServer() start");
-	
+
 	int sock_tcp;
 	sockaddr_in host_server;
 	socklen_t size = sizeof (sockaddr);
-	DataTransfer *trns = DataTransfer::getInstance();
 
 	host_server.sin_family = AF_INET;
 	host_server.sin_port = htons (Doclone::PORT_DATA);
@@ -105,7 +122,8 @@ void Unicast::tcpServer() throw(Exception) {
 				dcCommand response = Doclone::C_SERVER_OK;
 				DataTransfer::sendData(fd, &response, sizeof(response));
 
-				trns->pushFdd(fd, inet_ntoa (host_server.sin_addr));
+				this->_fds.push_back(fd);
+				this->_srcIP = inet_ntoa (host_server.sin_addr);
 
 				// Notify the views
 				Clone *dcl = Clone::getInstance();
@@ -116,7 +134,7 @@ void Unicast::tcpServer() throw(Exception) {
 			}
 		}
 	}
-	
+
 	close(sock_tcp);
 
 	log->debug("Unicast::tcpServer() end");
@@ -128,11 +146,9 @@ void Unicast::tcpServer() throw(Exception) {
  *
  * This function communicates with the function "tcpServer" of the server.
  */
-void Unicast::tcpClient() const throw(Exception) {
+void Unicast::tcpClient() throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Unicast::tcpClient() start");
-	
-	DataTransfer *trns = DataTransfer::getInstance();
 
 	int fd;
 	if ((fd = socket (AF_INET, SOCK_STREAM, 0)) < 0) {
@@ -155,7 +171,7 @@ void Unicast::tcpClient() const throw(Exception) {
 		ConnectionException ex;
 		throw ex;
 	}
-	
+
 	freeaddrinfo(res);
 
 	dcCommand request = Doclone::C_RECEIVER_OK;
@@ -169,7 +185,7 @@ void Unicast::tcpClient() const throw(Exception) {
 		throw ex;
 	}
 
-	trns->setFdo(fd);
+	this->_fds.push_back(fd);
 
 	log->debug("Unicast::tcpClient() end");
 }
@@ -180,14 +196,9 @@ void Unicast::tcpClient() const throw(Exception) {
  * \param image
  * 		The path for image file.
  */
-void Unicast::sendFromImage(const std::string &image) throw(Exception) {
+void Unicast::sendFromImage() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Unicast::sendFromImage(image=>%s) start", image.c_str());
-
-	uint64_t totalSize = Util::getFileSize(image);
-
-	DataTransfer *trns = DataTransfer::getInstance();
-	trns->setTotalSize(totalSize);
+	log->debug("Unicast::sendFromImage() start");
 
 	Operation *waitOp = new Operation(
 			Doclone::OP_WAIT_CLIENTS, "");
@@ -199,7 +210,7 @@ void Unicast::sendFromImage(const std::string &image) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_CLIENTS, "");
 
-	int fd = Util::openFile(image);
+	int fd = Util::openFile(this->_image);
 
 	Operation *transferOp = new Operation(
 			Doclone::OP_TRANSFER_DATA, "");
@@ -212,10 +223,15 @@ void Unicast::sendFromImage(const std::string &image) throw(Exception) {
 	 * If the system is little-endian, it is necessary to convert totalSize to
 	 * big-endian.
 	 */
-	uint64_t tmpTotalSize = htobe64(totalSize);
-	trns->transferFrom(&tmpTotalSize, static_cast<size_t>(sizeof(uint64_t)));
+	uint64_t totalSize = this->getImageSize(fd);
+	DataTransfer *trns = DataTransfer::getInstance();
+	trns->setTotalSize(totalSize);
 
-	trns->transferAllFrom(fd);
+	uint64_t tmpTotalSize = htobe64(totalSize);
+	DataTransfer::sendData(this->_fds, &tmpTotalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
+
+	trns->copyData(fd, this->_fds);
 
 	dcl->markCompleted(Doclone::OP_TRANSFER_DATA, "");
 
@@ -232,12 +248,12 @@ void Unicast::sendFromImage(const std::string &image) throw(Exception) {
  * \param device
  * 		The path for device.
  */
-void Unicast::sendFromDevice(const std::string &device) throw(Exception) {
+void Unicast::sendFromDevice() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Unicast::sendFromDevice(device=>%s) start", device.c_str());
+	log->debug("Unicast::sendFromDevice() start");
 
 	PartedDevice *pedDev = PartedDevice::getInstance();
-	pedDev->initialize(Util::getDiskPath(device));
+	pedDev->initialize(Util::getDiskPath(this->_device));
 
 	Operation *waitOp = new Operation(
 				Doclone::OP_WAIT_CLIENTS, "");
@@ -249,17 +265,16 @@ void Unicast::sendFromDevice(const std::string &device) throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_CLIENTS, "");
 
-	if(!Util::isBlockDevice(device)) {
+	if(!Util::isBlockDevice(this->_device)) {
 		NoBlockDeviceException ex;
 		throw ex;
 	}
 
 	PartedDevice *pDevice = PartedDevice::getInstance();
 	std::string target = pDevice->getPath();
-	Disk *dcDisk = DlFactory::createDiskLabel();
 	Image image;
 
-	if(Util::isDisk(device)) {
+	if(Util::isDisk(this->_device)) {
 		image.setType(Doclone::IMAGE_DISK);
 	}
 	else {
@@ -271,7 +286,7 @@ void Unicast::sendFromDevice(const std::string &device) throw(Exception) {
 
 	dcl->addOperation(readPartTableOp);
 
-	image.readPartitionTable(device);
+	image.readPartitionTable(this->_device);
 
 	// Mark the operation to read partition table as completed
 	dcl->markCompleted(Doclone::OP_READ_PARTITION_TABLE, target);
@@ -282,8 +297,8 @@ void Unicast::sendFromDevice(const std::string &device) throw(Exception) {
 	}
 
 	image.initCreateOperations();
-
-	image.createImageHeader(dcDisk);
+	image.initDiskReadArchive();
+	image.initFdWriteArchive(this->_fds);
 
 	/*
 	 * Before sending the data, it sends its size. So the client/s can
@@ -291,18 +306,27 @@ void Unicast::sendFromDevice(const std::string &device) throw(Exception) {
 	 * If the system is little-endian, it's necessary to convert totalSize to
 	 * big-endian.
 	 */
+	Disk *disk = image.getDisk();
+	uint8_t numPartitions = disk->getPartitions().size();
+	uint64_t tmpTotalSize = 0;
+	for(int i = 0;i<numPartitions;i++) {
+		tmpTotalSize += disk->getPartitions().at(i)->getMinSize();
+	}
 	DataTransfer *trns = DataTransfer::getInstance();
-	uint64_t tmpTotalSize = htobe64(image.getHeader().image_size);
-	(*trns->putNbytes) (trns->getFdd(), &tmpTotalSize,
+	trns->setTotalSize(tmpTotalSize);
+
+	tmpTotalSize = htobe64(tmpTotalSize);
+	DataTransfer::sendData(this->_fds, &tmpTotalSize,
 			static_cast<size_t>(sizeof(uint64_t)));
 
-	image.writeImageHeader();
+	image.saveImageHeader();
 
 	image.readPartitionsData();
 
-	this->closeConnection();
+	image.freeWriteArchive();
+	image.freeReadArchive();
 
-	delete dcDisk;
+	this->closeConnection();
 
 	log->debug("Unicast::sendFromDevice() end");
 }
@@ -318,9 +342,9 @@ void Unicast::send() throw(Exception) {
 
 	try {
 		if(dcl->getDevice().empty()) {
-			this->sendFromImage(dcl->getImage());
+			this->sendFromImage();
 		} else {
-			this->sendFromDevice(dcl->getDevice());
+			this->sendFromDevice();
 		}
 	} catch (const CancelException &ex) {
 		this->closeConnection();
@@ -345,11 +369,9 @@ void Unicast::send() throw(Exception) {
  * \param image
  * 		The path for image.
  */
-void Unicast::receiveToImage(const std::string &image) const throw(Exception) {
+void Unicast::receiveToImage() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Unicast::receiveToImage(image=>%s) start", image.c_str());
-
-	DataTransfer *trns = DataTransfer::getInstance();
+	log->debug("Unicast::receiveToImage() start");
 
 	Operation *waitOp = new Operation(
 			Doclone::OP_WAIT_SERVER, "");
@@ -361,8 +383,8 @@ void Unicast::receiveToImage(const std::string &image) const throw(Exception) {
 
 	dcl->markCompleted(Doclone::OP_WAIT_SERVER, "");
 
-	Util::createFile(image);
-	int fd = Util::openFile(image);
+	Util::createFile(this->_image);
+	int fd = Util::openFile(this->_image);
 
 	Operation *transferOp = new Operation(
 			Doclone::OP_TRANSFER_DATA, "");
@@ -373,16 +395,18 @@ void Unicast::receiveToImage(const std::string &image) const throw(Exception) {
 	 * Get the size of the data, in order to calculate the completed percentage.
 	 */
 	uint64_t totalSize;
-	trns->transferTo(&totalSize, static_cast<size_t>(sizeof(uint64_t)));
+	DataTransfer::recvData(this->_fds[0], &totalSize,
+			static_cast<size_t>(sizeof(uint64_t)));
 
 	/*
 	 * The given totalSize is received in big-endian. If the system is
 	 * little-endian, it must be converted to little-endian.
 	 */
 	uint64_t tmpTotalSize = be64toh(totalSize);
+	DataTransfer *trns = DataTransfer::getInstance();
 	trns->setTotalSize(tmpTotalSize);
 
-	trns->transferAllTo(fd);
+	trns->copyData(this->_fds[0], fd);
 
 	dcl->markCompleted(Doclone::OP_TRANSFER_DATA, "");
 
@@ -399,12 +423,12 @@ void Unicast::receiveToImage(const std::string &image) const throw(Exception) {
  * \param device
  * 		The path for device.
  */
-void Unicast::receiveToDevice(const std::string &device) const throw(Exception) {
+void Unicast::receiveToDevice() throw(Exception) {
 	Logger *log = Logger::getInstance();
-	log->debug("Unicast::receiveToDevice(device=>%s) start", device.c_str());
+	log->debug("Unicast::receiveToDevice() start");
 
 	PartedDevice *pedDev = PartedDevice::getInstance();
-	pedDev->initialize(Util::getDiskPath(device));
+	pedDev->initialize(Util::getDiskPath(this->_device));
 
 	Operation *waitOp = new Operation(
 				Doclone::OP_WAIT_SERVER, "");
@@ -416,7 +440,7 @@ void Unicast::receiveToDevice(const std::string &device) const throw(Exception)
 
 	dcl->markCompleted(Doclone::OP_WAIT_SERVER, "");
 
-	if(!Util::isBlockDevice(device)) {
+	if(!Util::isBlockDevice(this->_device)) {
 		NoBlockDeviceException ex;
 		throw ex;
 	}
@@ -425,46 +449,36 @@ void Unicast::receiveToDevice(const std::string &device) const throw(Exception)
 	 * Get the size of the data, in order to calculate the completed percentage.
 	 */
 	uint64_t totalSize;
-	DataTransfer *trns = DataTransfer::getInstance();
-	DataTransfer::recvData(trns->getFdo(), &totalSize,
+	DataTransfer::recvData(this->_fds[0], &totalSize,
 			static_cast<size_t>(sizeof(uint64_t)));
 
 	/*
 	 * The given totalSize is received in big-endian. If the system is
-	 * little-endian, it must be converted to little-endian.
+	 * little-endian, it must be converted.
 	 */
 	uint64_t tmpTotalSize = be64toh(totalSize);
+	DataTransfer *trns = DataTransfer::getInstance();
 	trns->setTotalSize(tmpTotalSize);
 
 	Image image;
+	image.initFdReadArchive(this->_fds[0]);
+	image.initDiskWriteArchive();
+	image.loadImageHeader();
 
-	image.readImageHeader(device);
-
-	image.openImageHeader();
-
-	Disk *dcDisk = DlFactory::createDiskLabel(image.getLabelType(),
-			pedDev->getPath());
-
-	if(image.canRestoreCheck(device, dcDisk->getSize()) == false) {
+	if(image.canRestoreCheck(this->_device) == false) {
 		RestoreImageException ex;
 		throw ex;
 	}
 
-	image.initRestoreOperations(device);
+	image.initRestoreOperations(this->_device);
+	image.writePartitionTable(this->_device);
+	image.writePartitionsData(this->_device);
 
-	image.writePartitionTable(device);
-
-	image.writePartitionsData();
-
-	if(image.getHeader().image_type==(Doclone::imageType)IMAGE_DISK) {
-		dcDisk->setPartitions(image.getPartitions());
-		dcDisk->restoreGrub();
-	}
+	image.freeWriteArchive();
+	image.freeReadArchive();
 
 	this->closeConnection();
 
-	delete dcDisk;
-
 	log->debug("Unicast::receiveToDevice() end");
 }
 
@@ -481,9 +495,9 @@ void Unicast::receive() throw(Exception) {
 
 	try {
 		if(dcl->getDevice().empty()) {
-			this->receiveToImage(dcl->getImage());
+			this->receiveToImage();
 		} else {
-			this->receiveToDevice(dcl->getDevice());
+			this->receiveToDevice();
 		}
 	} catch (const CancelException &ex) {
 		this->closeConnection();
@@ -502,4 +516,24 @@ void Unicast::receive() throw(Exception) {
 	log->debug("Unicast::receive() end");
 }
 
+/**
+ * \brief Closes the opened connections
+ */
+void Unicast::closeConnection() throw(Exception) {
+	Logger *log = Logger::getInstance();
+	log->debug("Unicast::closeConnection() start");
+
+	if(this->_fds.size() > 0) {
+		std::vector<int>::iterator it;
+		for(it = this->_fds.begin(); it != this->_fds.end(); ++it) {
+			if(close(*it)<0) {
+				CloseConnectionException ex;
+				ex.logMsg();
+			}
+		}
+	}
+
+	log->debug("Unicast::closeConnection() end");
+}
+
 }
