@@ -24,7 +24,7 @@
 
 namespace Doclone {
 
-Mac::Mac(const std::string &path) : DiskLabel(path) {
+Mac::Mac() {
 	this->_labelType = DISK_TYPE_MAC;
 	this->_partedName = "mac";
 }
@@ -62,8 +62,8 @@ void Mac::readPartitions() throw(Exception) {
 			try {
 				std::string path=
 						Util::buildPartPath(pedPart->disk->dev->path, pedPart->num);
-				// These Partition objects will be destroyed in Image::~Image()
-				Partition *part = new Partition (path);
+				Partition *part = new Partition();
+				part->initFromPath(path);
 				this->_partitions.push_back(part);
 			}
 			catch(const WarningException &ex) {
