@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ namespace Doclone {
 Ext2::Ext2() {
 	Logger *log = Logger::getInstance();
 	log->debug("Ext2::Ext2() start");
-	
+
 	this->_type = Doclone::FSTYPE_UNIX;
 	this->_mountType = Doclone::MOUNT_NATIVE;
 	this->_docloneName="ext2";
@@ -50,9 +50,9 @@ Ext2::Ext2() {
 	this->_formatOptions="-t ext2";
 	this->_adminCommand="";
 	this->_code = Doclone::FS_EXT2;
-	
+
 	this->checkSupport();
-	
+
 	log->debug("Ext2::Ext2() end");
 }
 
@@ -62,10 +62,10 @@ Ext2::Ext2() {
 void Ext2::checkSupport() {
 	Logger *log = Logger::getInstance();
 	log->debug("Ext2::checkSupport() start");
-	
+
 	// Mounting support
 	this->_mountSupport = true;
-	
+
 	// Formatting support
 	if(Util::find_program_in_path(this->_command).empty()) {
 		this->_formatSupport = false;
@@ -73,11 +73,11 @@ void Ext2::checkSupport() {
 	else {
 		this->_formatSupport = true;
 	}
-	
+
 	// UUID and label support
 	this->_uuidSupport = true;
 	this->_labelSupport = true;
-	
+
 	log->debug("Ext2::checkSupport() end");
 }
 
@@ -90,20 +90,21 @@ void Ext2::checkSupport() {
 void Ext2::writeLabel(const std::string &dev) const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Ext2::writeLabel(dev=>%s) start", dev.c_str());
-	
+
 	ext2_filsys fs;
+	memset(&fs, 0, sizeof(fs));
 	ext2_super_block *sb;
 	dgrp_t i;
 	int set_csum = 0;
 
-	ext2fs_open2 (dev.c_str(), 0, EXT2_FLAG_RW | EXT2_FLAG_JOURNAL_DEV_OK,
-				  0, 0, unix_io_manager, &fs);
+	errcode_t retVal = ext2fs_open(dev.c_str(),
+			EXT2_FLAG_RW|EXT2_FLAG_JOURNAL_DEV_OK, 0, 0, unix_io_manager, &fs);
 
-	if (!fs) {
+	if (retVal) {
 		WriteLabelException ex(dev);
-		ex.logMsg();
+		throw ex;
 	}
-	
+
 	sb = fs->super;
 	fs->flags &= ~EXT2_FLAG_MASTER_SB_ONLY;
 	fs->flags |= EXT2_FLAG_SUPER_ONLY;
@@ -123,7 +124,7 @@ void Ext2::writeLabel(const std::string &dev) const throw(Exception) {
 	}
 
 	memset(sb->s_volume_name, 0, sizeof(sb->s_volume_name));
-	strncpy(sb->s_volume_name, this->_label.c_str(),
+	Util::safe_strncpy(sb->s_volume_name, this->_label.c_str(),
 			sizeof(sb->s_volume_name));
 
 	if (set_csum) {
@@ -134,7 +135,7 @@ void Ext2::writeLabel(const std::string &dev) const throw(Exception) {
 
 	ext2fs_mark_super_dirty(fs);
 	ext2fs_close(fs);
-	
+
 	log->debug("Ext2::writeLabel() end");
 }
 
@@ -147,7 +148,7 @@ void Ext2::writeLabel(const std::string &dev) const throw(Exception) {
 void Ext2::writeUUID(const std::string &dev) const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("Ext2::writeUUID(dev=>%s) start", dev.c_str());
-	
+
 	ext2_filsys fs;
 	ext2_super_block *sb;
 	dgrp_t i;
@@ -158,13 +159,13 @@ void Ext2::writeUUID(const std::string &dev) const throw(Exception) {
 
 	if (!fs) {
 		WriteUuidException ex(dev);
-		ex.logMsg();
+		throw ex;
 	}
-	
+
 	sb = fs->super;
 	fs->flags &= ~EXT2_FLAG_MASTER_SB_ONLY;
 	fs->flags |= EXT2_FLAG_SUPER_ONLY;
-	
+
 	if (sb->s_feature_ro_compat &
 		EXT4_FEATURE_RO_COMPAT_GDT_CSUM) {
 		/*
@@ -178,22 +179,22 @@ void Ext2::writeUUID(const std::string &dev) const throw(Exception) {
 		if (i >= fs->group_desc_count)
 			set_csum = 1;
 	}
-	
-	 // Write the uuid
+
+	// Write the uuid
 	if (uuid_parse (this->_uuid.c_str(), sb->s_uuid)<0) {
 		WriteUuidException ex(dev);
 		ex.logMsg();
 	}
-	
+
 	if (set_csum) {
 		for (i = 0; i < fs->group_desc_count; i++)
 			ext2fs_group_desc_csum_set(fs, i);
 		fs->flags &= ~EXT2_FLAG_SUPER_ONLY;
 	}
-	
+
 	ext2fs_mark_super_dirty (fs);
 	ext2fs_close(fs);
-	
+
 	log->debug("Ext2::writeUUID() end");
 }
 /**@}*/
