@@ -1,6 +1,6 @@
 /*
  *  libdoclone - library for cloning GNU/Linux systems
- *  Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ *  Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ namespace Doclone {
 LinuxSwap::LinuxSwap() {
 	Logger *log = Logger::getInstance();
 	log->debug("LinuxSwap::LinuxSwap() start");
-	
+
 	this->_type = Doclone::FSTYPE_NONE;
 	this->_mountType = Doclone::MOUNT_NATIVE;
 	this->_docloneName="linux-swap";
@@ -49,9 +49,9 @@ LinuxSwap::LinuxSwap() {
 	this->_formatOptions="-v1";
 	this->_adminCommand="";
 	this->_code = Doclone::FS_LINUXSWAP;
-	
+
 	this->checkSupport();
-	
+
 	log->debug("LinuxSwap::LinuxSwap() end");
 }
 
@@ -61,10 +61,10 @@ LinuxSwap::LinuxSwap() {
 void LinuxSwap::checkSupport() {
 	Logger *log = Logger::getInstance();
 	log->debug("LinuxSwap::checkSupport() start");
-	
+
 	// Mounting support
 	this->_mountSupport = false;
-	
+
 	// Formatting support
 	if(Util::find_program_in_path(this->_command) .empty()) {
 		this->_formatSupport = false;
@@ -72,13 +72,13 @@ void LinuxSwap::checkSupport() {
 	else {
 		this->_formatSupport = true;
 	}
-	
+
 	// UUID and label support
 	this->_uuidSupport = true;
 
 	// Label support
 	this->_labelSupport = true;
-	
+
 	log->debug("LinuxSwap::checkSupport() end");
 }
 
@@ -96,7 +96,7 @@ void LinuxSwap::writeLabel(const std::string &dev) const throw(Exception) {
 	}
 	catch(const Exception &e) {
 		WriteLabelException ex(dev);
-		ex.logMsg();
+		throw ex;
 	}
 
 	log->debug("LinuxSwap::writeLabel() end");
@@ -112,16 +112,20 @@ void LinuxSwap::writeUUID(const std::string &dev) const throw(Exception) {
 	Logger *log = Logger::getInstance();
 	log->debug("LinuxSwap::writeUUID(dev=>%s) start", dev.c_str());
 
+	uuid_t binUuid;
+
+	// Convert to binary UUID
+	if (uuid_parse(this->_uuid.c_str(), binUuid)<0) {
+		WriteUuidException ex(dev);
+		ex.logMsg();
+	}
+
 	try {
-		uuid_t binUuid;
-
-		uuid_parse(this->_uuid.c_str(), binUuid);
-
 		Util::writeBinData(dev, &binUuid, 0x40C, 16);
 	}
 	catch(const Exception &e) {
 		WriteUuidException ex(dev);
-		ex.logMsg();
+		throw ex;
 	}
 
 	log->debug("LinuxSwap::writeUUID() end");
