@@ -1,6 +1,6 @@
 /*
  * doclone - a frontend for libdoclone
- * Copyright (C) 2013 Joan Lledó <joanlluislledo@gmail.com>
+ * Copyright (C) 2013, 2015 Joan Lledó <joanlluislledo@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ void ConsoleView::notify(Doclone::dcTransferEvent event, const uint64_t numBytes
 	case Doclone::TRANS_TRANSFERRED_BYTES: {
 		if(this->_totalSize>0) {
 			// Calculate and print the percentage of data transferred
-			float rate = numBytes/static_cast<float>(this->_totalSize);
+			double rate = numBytes/static_cast<double>(this->_totalSize);
 			int percent = floor(rate*100);
 			if(this->_percent != percent) {
 				this->_percent = percent;
@@ -85,7 +85,7 @@ void ConsoleView::notify(Doclone::dcOperationEvent event,
 			break;
 		}
 		case Doclone::OP_TRANSFER_DATA: {
-			std::cout << _("Transferring data...") << " " << target << std::endl;
+			std::cout << _("Transferring data...") << std::endl;
 
 			break;
 		}
@@ -122,20 +122,20 @@ void ConsoleView::notify(Doclone::dcOperationEvent event,
 		break;
 	}
 	case Doclone::OP_WRITE_PARTITION_FLAGS: {
-		// TO TRANSLATORS: looks like Written the fs flags of /dev/sdb1
-		std::cout << _("Written the fs flags of") << " " << target << std::endl;
+		// TO TRANSLATORS: looks like FS flags written: /dev/sdb1
+		std::cout << _("FS flags written:") << " " << target << std::endl;
 
 		break;
 	}
 	case Doclone::OP_WRITE_FS_LABEL: {
-		// TO TRANSLATORS: looks like Written the fs label of /dev/sdb1
-		std::cout << _("Written the fs label of") << " " << target << std::endl;
+		// TO TRANSLATORS: looks like FS label written: /dev/sdb1
+		std::cout << _("FS label written:") << " " << target << std::endl;
 
 		break;
 	}
 	case Doclone::OP_WRITE_FS_UUID: {
-		// TO TRANSLATORS: looks like Written the fs uuid of /dev/sdb1
-		std::cout << _("Written the fs uuid of") << " " << target << std::endl;
+		// TO TRANSLATORS: looks like FS UUID written: /dev/sdb1
+		std::cout << _("FS UUID written:") << " " << target << std::endl;
 
 		break;
 	}
@@ -146,7 +146,7 @@ void ConsoleView::notify(Doclone::dcOperationEvent event,
 		break;
 	}
 	case Doclone::OP_WRITE_DATA: {
-		// TO TRANSLATORS: looks like Data written to /dev/sdb1
+		// TO TRANSLATORS: looks like Data written to /dev/sdb
 		std::cout << _("Data written to") << " " << target << std::endl;
 
 		break;
@@ -202,9 +202,10 @@ void ConsoleView::initView(int argc, char **argv) const {
 	std::string image="";
 	std::string device="";
 	std::string address="";
+	std::string interface="";
 	int nodesNumber = 0;
 
-	const char options_c[] = "hvcrSRsld:f:a:n:eF";
+	const char options_c[] = "hvcrSRsld:f:a:i:n:eF";
 	const struct option options_l[] = {
 		{"help", 0, 0, 'h'},
 		{"version", 0, 0, 'v'},
@@ -217,6 +218,7 @@ void ConsoleView::initView(int argc, char **argv) const {
 		{"device", 1, 0, 'd'},
 		{"file", 1, 0, 'f'},
 		{"address", 1, 0, 'a'},
+		{"interface", 1, 0, 'i'},
 		{"nodes", 1, 0, 'n'},
 		{"empty", 0, 0, 'e'},
 		{"force", 0, 0, 'F'},
@@ -273,7 +275,7 @@ void ConsoleView::initView(int argc, char **argv) const {
 			break;
 		}
 		case 'f': {
-			if (!strrchr (optarg, '/'))	{ // If it is a relative path 
+			if (!strrchr (optarg, '/'))	{ // If it is a relative path
 				char tmp[256];
 				snprintf (tmp, sizeof(tmp), "./%s", optarg);
 				image = tmp;
@@ -295,6 +297,11 @@ void ConsoleView::initView(int argc, char **argv) const {
 			dcl->setAddress(address);
 			break;
 		}
+		case 'i': {
+			interface = optarg;
+			dcl->setInterface(interface);
+			break;
+		}
 		case 'n': {
 			nodesNumber = atoi (optarg);
 			dcl->setNodesNumber(nodesNumber);
@@ -412,6 +419,7 @@ void ConsoleView::usage (FILE * stream, int code, const char * cmd) const {
 			"[ -d, --device DEVICE ] [ -f, --file FILE ]\n"
 			"\t[ -a, --address SERVER-IP-ADDRESS ]"
 			" [ -n, --nodes NUMBER ]\n"
+			"\t[ -i, --interface IP-OF-WORKING-INTERFACE]\n"
 			"\t[ -e, --empty ] [ -F, --force]\n "), cmd);
 
 	fprintf (stream,
